from cntext.dictionary import *
from cntext.sentiment import senti_by_dutir, senti_by_hownet, senti_by_diydict, init_jieba
from cntext.similarity import similarity_score
from cntext.stats import term_freq, readability
from cntext.plot import wordcloud, wordshiftor

